<?php
/**
 * phpillow CouchDB backend
 *
 * This file is part of phpillow.
 *
 * phpillow is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; version 3 of the License.
 *
 * phpillow is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with phpillow; if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @package Core
 * @version arbit-0.6-beta
 * @license http://www.gnu.org/licenses/lgpl-3.0.txt LGPL
 */

/**
 * Validate email addresses
 *
 * @package Core
 * @version arbit-0.6-beta
 * @license http://www.gnu.org/licenses/lgpl-3.0.txt LGPL
 */
class phpillowEmailValidator extends phpillowValidator
{
    /**
     * Validate input as an email address
     *
     * @param mixed $input
     * @return string
     */
    public function validate( $input )
    {
        // Check if the input is a valid email address using a bit simplified
        // version of the mail address specification in RFC 2822.
        if ( !preg_match( '(^[a-z0-9!#$%&\'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&\'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?$)i', $input ) )
        {
            throw new phpillowValidationException(
                'Invalid mail address provided: %email',
                array(
                    'email' => $input,
                )
            );
        }

        return (string) $input;
    }
}

